@@ -1,5 +1,7 @@
 # Following instructions:
 # http://cran.r-project.org/web/packages/helloJavaWorld/vignettes/helloJavaWorld.pdf
 
-.onLoad <- function (libname, pkgname)
-  .jpackage(pkgname, lib.loc = libname)
+.onLoad <- function (libname, pkgname) {
+  rJava::.jpackage(pkgname, lib.loc = libname)
+}
+
